# Contributing

## about the widget

Documenting this for myself mostly:
- There is a bundling step involved because we're importing a local Javascript
file in `widget.js`. 
    - There's more information about it in the [anywidget
    docs](https://anywidget.dev/en/bundling/), but naturally I skipped over it
    until I actually encountered this need in a project.
- The Javascript file that contains the widget frontend
(`src/scattered/widget.js`) is generated by esbuild (from `lib/widget.js`), and
it is .gitignored. It should be generated by running `pnpm widget-dev` or `pnpm
widget-build`.
